==> libreoffice-fresh-sdk-25.2.3-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.js <==
var servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation =
[
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XPresentation", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aa13f6304544fd5f3088b37c3d07b8d65", null ],
    [ "AllowAnimations", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a87df052c1626fb6009e1fdb27e60b9b9", null ],
    [ "CustomShow", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#ade4b2f0ed2443820755a342bebd271e6", null ],
    [ "FirstPage", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aff89df106d6a6547bc73e3898c9f4907", null ],
    [ "IsAlwaysOnTop", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a72f740d67fe6a6918ae8ba5c22506db0", null ],
    [ "IsAutomatic", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aef8673876c856dba7a150226a26bc77d", null ],
    [ "IsEndless", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a0e956c66caf988df1cfef61f56abeec6", null ],
    [ "IsFullScreen", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a80d12cf95fc174f24632fe23a68ecdcf", null ],
    [ "IsLivePresentation", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a5f431792adaf903401046a85880e9160", null ],
    [ "IsMouseVisible", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aba6c49586b1fbd3ab7d3e5e1dbb7987d", null ],
    [ "Pause", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a00b06120d92cbd974103f4253a271804", null ],
    [ "StartWithNavigator", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a9c15021faf8529b08a44e331c78e0f88", null ],
    [ "UsePen", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#ae8820b588c5eb941f353c073b72a53dc", null ]
];

==> libreoffice-fresh-sdk-25.8.2-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.js <==
var servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::presentation::XPresentation", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aa13f6304544fd5f3088b37c3d07b8d65", null ],
    [ "AllowAnimations", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a87df052c1626fb6009e1fdb27e60b9b9", null ],
    [ "CustomShow", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#ade4b2f0ed2443820755a342bebd271e6", null ],
    [ "FirstPage", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aff89df106d6a6547bc73e3898c9f4907", null ],
    [ "IsAlwaysOnTop", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a72f740d67fe6a6918ae8ba5c22506db0", null ],
    [ "IsAutomatic", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aef8673876c856dba7a150226a26bc77d", null ],
    [ "IsEndless", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a0e956c66caf988df1cfef61f56abeec6", null ],
    [ "IsFullScreen", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a80d12cf95fc174f24632fe23a68ecdcf", null ],
    [ "IsLivePresentation", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a5f431792adaf903401046a85880e9160", null ],
    [ "IsMouseVisible", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#aba6c49586b1fbd3ab7d3e5e1dbb7987d", null ],
    [ "Pause", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a00b06120d92cbd974103f4253a271804", null ],
    [ "StartWithNavigator", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#a9c15021faf8529b08a44e331c78e0f88", null ],
    [ "UsePen", "servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html#ae8820b588c5eb941f353c073b72a53dc", null ]
];
